@@ -35,14 +35,15 @@
 #' \item Simulation control: \code{\link{stepn}}, \code{\link{run}},
 #' \code{\link{now}}, \code{\link{peek}}, \code{\link{reset}}
 #'
-#' \item Resources: \code{\link{add_resource}}, \code{\link{get_capacity}},
-#' \code{\link{get_queue_size}}, \code{\link{get_server_count}},
-#' \code{\link{get_queue_count}}, \code{\link{get_capacity_selected}},
-#' \code{\link{get_queue_size_selected}}, \code{\link{get_server_count_selected}},
-#' \code{\link{get_queue_count_selected}}
+#' \item Resources: \code{\link{add_resource}}, \code{\link{get_resources}},
+#' \code{\link{get_capacity}}, \code{\link{get_queue_size}},
+#' \code{\link{get_server_count}}, \code{\link{get_queue_count}},
+#' \code{\link{get_capacity_selected}}, \code{\link{get_queue_size_selected}},
+#' \code{\link{get_server_count_selected}}, \code{\link{get_queue_count_selected}}
 #'
 #' \item Sources: \code{\link{add_generator}}, \code{\link{add_dataframe}},
-#' \code{\link{get_n_generated}}
+#' \code{\link{get_sources}}, \code{\link{get_n_generated}},
+#' \code{\link{get_trajectory}}
 #'
 #' \item Data retrieval: \code{\link{get_mon_arrivals}},
 #' \code{\link{get_mon_attributes}}, \code{\link{get_mon_resources}}
@@ -318,6 +319,26 @@ get_mon_resources <- function(.envs)
 get_mon_resources.simmer <- function(.envs)
   envs_apply(.envs, "get_mon_resources")
 
+#' Get Sources and Resources Defined
+#'
+#' Get a list of names of sources or resources defined in a simulation environment.
+#'
+#' @inheritParams reset
+#'
+#' @return A character vector.
+#' @export
+get_sources <- function(.env) UseMethod("get_sources")
+
+#' @export
+get_sources.simmer <- function(.env) names(.env$get_sources())
+
+#' @rdname get_sources
+#' @export
+get_resources <- function(.env) UseMethod("get_resources")
+
+#' @export
+get_resources.simmer <- function(.env) names(.env$get_resources())
+
 #' Get Process Parameters
 #'
 #' Getters for processes (sources and arrivals) number of arrivals generated
@@ -328,23 +349,33 @@ get_mon_resources.simmer <- function(.envs)
 #' @param source the name of the source.
 #'
 #' @details \code{get_n_generated} returns the number of arrivals generated by a
-#' given source.
+#' given source. \code{get_trajectory} returns the trajectory to which it is
+#' attached.
 #'
 #' \code{get_name} returns the number of the running arrival. \code{get_attribute}
-#' returns a running arrival's attributes or global ones. If a provided key was
-#' not previously set, it returns a missing value. \code{get_global} is a shortcut
-#' for \code{get_attribute(global=TRUE)}. \code{get_prioritization} returns a
-#' running arrival's prioritization values. \code{get_name}, \code{get_attribute}
-#' and \code{get_prioritization} are meant to be used inside a trajectory; otherwise,
-#' there will be no arrival running and these functions will throw an error.
+#' returns a running arrival's attributes. If a provided key was not previously
+#' set, it returns a missing value. \code{get_global} returns a global attribute.
+#' \code{get_prioritization} returns a running arrival's prioritization values.
+#' \code{get_name}, \code{get_attribute} and \code{get_prioritization} are meant
+#' to be used inside a trajectory; otherwise, there will be no arrival running
+#' and these functions will throw an error.
 #'
-#' @seealso \code{\link{set_attribute}}, \code{\link{set_prioritization}}.
+#' @seealso \code{\link{get_sources}}, \code{\link{set_trajectory}},
+#' \code{\link{set_attribute}}, \code{\link{set_global}},
+#' \code{\link{set_prioritization}}.
 #' @export
 get_n_generated <- function(.env, source) UseMethod("get_n_generated")
 
 #' @export
 get_n_generated.simmer <- function(.env, source) .env$get_n_generated(source)
 
+#' @rdname get_n_generated
+#' @export
+get_trajectory <- function(.env, source) UseMethod("get_trajectory")
+
+#' @export
+get_trajectory.simmer <- function(.env, source) .env$get_trajectory(source)
+
 #' @rdname get_n_generated
 #' @export
 get_name <- function(.env) UseMethod("get_name")
@@ -353,18 +384,27 @@ get_name <- function(.env) UseMethod("get_name")
 get_name.simmer <- function(.env) .env$get_name()
 
 #' @param keys the attribute name(s).
-#' @param global if \code{TRUE}, the attribute will be global instead of per-arrival.
+#' @inheritParams set_attribute
 #'
 #' @rdname get_n_generated
 #' @export
-get_attribute <- function(.env, keys, global=FALSE) UseMethod("get_attribute")
+get_attribute <- function(.env, keys, global=FALSE) {
+  if (global) {
+    .Deprecated("get_global", old="get_attribute(global=TRUE)")
+    get_global(.env, keys)
+  }
+  else UseMethod("get_attribute")
+}
 
 #' @export
-get_attribute.simmer <- function(.env, keys, global=FALSE) .env$get_attribute(keys, global)
+get_attribute.simmer <- function(.env, keys, global=FALSE) .env$get_attribute(keys)
 
 #' @rdname get_n_generated
 #' @export
-get_global <- function(.env, keys) get_attribute(.env, keys, TRUE)
+get_global <- function(.env, keys) UseMethod("get_global")
+
+#' @export
+get_global.simmer <- function(.env, keys) .env$get_global(keys)
 
 #' @rdname get_n_generated
 #' @export
@@ -382,7 +422,8 @@ get_prioritization.simmer <- function(.env) .env$get_prioritization()
 #' @param resource the name of the resource.
 #'
 #' @return Return a numeric value.
-#' @seealso \code{\link{set_capacity}}, \code{\link{set_queue_size}}.
+#' @seealso \code{\link{get_resources}}, \code{\link{set_capacity}},
+#' \code{\link{set_queue_size}}.
 #' @export
 get_capacity <- function(.env, resource) UseMethod("get_capacity")
 
